# xEditor Demo

First editor
<div id="foo"> <div class="smartEditable"> <P><EM><STRONG>smart</STRONG></EM>Editor<STRONG> rocks !</STRONG></P> </div> </div> <div id="bar"> <div class="smartEditable">Block</div> </div> <div class="smartEditable"> <div id="foobar" class="smartEditableStyle"> Smart editable style </div> </div> <div>non editable content</div> <br /> <div class="smartEditable">editable content</div> <div>non editable content</div> <div class="smartEditable">editable content</div> <br />
Second editor
<div id="foo"> <div class="smartEditable"> <P><EM><STRONG>smart</STRONG></EM>Editor<STRONG> rocks !</STRONG></P> </div> </div> <div id="bar"> <div class="smartEditable">Block</div> </div> <div class="smartEditable"> <div id="foobar" class="smartEditableStyle"> Smart editable style </div> </div> <div>non editable content</div> <br /> <div class="smartEditable">editable content</div> <div>non editable content</div> <div class="smartEditable">editable content</div> <br />

# QUnit example

##

##